Create an orderly runner, a porcelain object

api(
  repositories_base_path,
  validate = NULL,
  log_level = "info",
  lib_path = "/library",
  skip_queue_creation = FALSE
)

Arguments

repositories_base_path

Path in which Git repositories are cloned.

validate

Logical, indicating if validation should be done on responses. This should be FALSE in production environments. See porcelain::porcelain for details

log_level

Logging level to use. Sensible options are "off", "info" and "all".

lib_path

Path to library to list packages from in the /library/list endpoint. This is expected to be a shared library that workers have access to, mounted from the host machine. It should only be used for testing, since the workers have a hard-coded library mountpoint path of "/library" (as per Dockerfile). See https://github.com/vimc/montagu-config/tree/main/packages for more details.

skip_queue_creation

Skip queue creation, this is primarily used for tests where we can't establish a Redis connection.

Value

A porcelain::porcelain object. Notably this does not start the server