Get the difference between two tree-ish

git_diff_tree(left, right, repo = NULL)

Arguments

left

the tree-ish to use as the base for the comparison.

right

the tree-ish to compare to the base.

repo

the path to the Git repo to use.

Value

a dataframe for each differing entry in the trees, with columns mode1, mode2, hash1, hash2, status, score, src and dst.