If the path is a directory, any modification to files contained within it are considered.

git_get_latest_commit(path, ref, repo = NULL)

Arguments

path

path to the file of directory to search for

ref

the Git commit from which to start the search. Only ancestors of that commit will be considered.

repo

the path to the Git repo to use.