R/git.R
git_diff_tree.Rd
Get the difference between two tree-ish
git_diff_tree(left, right, repo = NULL)
the tree-ish to use as the base for the comparison.
the tree-ish to compare to the base.
the path to the Git repo to use.
a dataframe for each differing entry in the trees, with columns mode1, mode2, hash1, hash2, status, score, src and dst.
mode1
mode2
hash1
hash2
status
score
src
dst