Clone or fetch a remote repository.
git_sync(base, url, ssh_key = NULL)
Arguments
- base
the base directory in which all repositories are stored.
- url
the URL of the remote repository.
- ssh_key
private SSH key for connecting to private repositories
(Optional, default is NULL).
Value
the path to the local clone of the repository.