Repositories are all stored as subdirectories of a common base path,
using a hash of their URL as the directory name.
repository_path(base, url, check = TRUE)
Arguments
- base
the base directory in which all repositories are stored.
- url
the URL of the remote repository.
- check
if TRUE and the repository does not exist locally yet, an error
is raised.
Value
the path to the repository.